@@ -1,28 +1,16 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KPIMTEXTEDITRICHTEXTCOMPOSEREMAILQUOTEHIGHLIGHTER_H
 #define KPIMTEXTEDITRICHTEXTCOMPOSEREMAILQUOTEHIGHLIGHTER_H
 
-#include <sonnet/highlighter.h>
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit {
+#include <sonnet/highlighter.h>
+namespace KPIMTextEdit
+{
 class RichTextComposer;
 /**
  * @short A highlighter for email quoting.
@@ -34,12 +22,15 @@ class KPIMTEXTEDIT_EXPORT RichTextComposerEmailQuoteHighlighter : public Sonnet:
 {
     Q_OBJECT
 public:
-
     /**
      * Constructor. See setQuoteColor() for the parameters.
      * FIXME: Default colors don't obey color scheme
      */
-    explicit RichTextComposerEmailQuoteHighlighter(RichTextComposer *textEdit, const QColor &normalColor = Qt::black, const QColor &quoteDepth1 = QColor(0x00, 0x80, 0x00), const QColor &quoteDepth2 = QColor(0x00, 0x80, 0x00), const QColor &quoteDepth3 = QColor(0x00, 0x80, 0x00),
+    explicit RichTextComposerEmailQuoteHighlighter(RichTextComposer *textEdit,
+                                                   const QColor &normalColor = Qt::black,
+                                                   const QColor &quoteDepth1 = QColor(0x00, 0x80, 0x00),
+                                                   const QColor &quoteDepth2 = QColor(0x00, 0x80, 0x00),
+                                                   const QColor &quoteDepth3 = QColor(0x00, 0x80, 0x00),
                                                    const QColor &misspelledColor = Qt::red);
 
     ~RichTextComposerEmailQuoteHighlighter() override;
@@ -54,7 +45,11 @@ public:
      * @param normalColor will be ignored, only provided for KNode
      *                    compatibility.
      */
-    void setQuoteColor(const QColor &normalColor, const QColor &quoteDepth1, const QColor &quoteDepth2, const QColor &quoteDepth3, const QColor &misspelledColor = Qt::red);
+    void setQuoteColor(const QColor &normalColor,
+                       const QColor &quoteDepth1,
+                       const QColor &quoteDepth2,
+                       const QColor &quoteDepth3,
+                       const QColor &misspelledColor = Qt::red);
 
     /**
      * Turns spellcheck highlighting on or off.
@@ -67,8 +62,8 @@ public:
      * Reimplemented to highlight quote blocks.
      */
     void highlightBlock(const QString &text) override;
-protected:
 
+protected:
     /**
      * Reimplemented, the base version sets the text color to black, which
      * is not what we want. We do nothing, the format is already reset by
