@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,11 +12,12 @@
 #include "texteditor/plaintexteditor/plaintexteditorwidget.h"
 
 #include <QDialogButtonBox>
+#include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <QLabel>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class InsertHtmlDialogPrivate
 {
 public:
@@ -24,12 +25,12 @@ public:
         : q(qq)
     {
         q->setWindowTitle(i18nc("@title:window", "Insert HTML"));
-        auto *lay = new QVBoxLayout(q);
+        auto lay = new QVBoxLayout(q);
         QLabel *label = new QLabel(i18n("Insert HTML tags and texts:"));
         lay->addWidget(label);
         editor = new InsertHtmlEditor;
         editor->setSpellCheckingSupport(false);
-        auto *editorWidget = new KPIMTextEdit::PlainTextEditorWidget(editor);
+        auto editorWidget = new KPIMTextEdit::PlainTextEditorWidget(editor);
         lay->addWidget(editorWidget);
         label = new QLabel(i18n("Example: <i> Hello word </i>"));
         QFont font = label->font();
@@ -47,8 +48,8 @@ public:
 
         lay->addWidget(buttonBox);
         q->connect(editor, &InsertHtmlEditor::textChanged, q, [this]() {
-                _k_slotTextChanged();
-            });
+            _k_slotTextChanged();
+        });
         okButton->setEnabled(false);
         q->resize(640, 480);
     }
