@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,17 +10,18 @@
 
 #include <QDialog>
 
-#include "kpimtextedit_private_export.h"
 #include "kpimtextedit/plaintexteditor.h"
+#include "kpimtextedit_private_export.h"
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class InsertHtmlDialogPrivate;
 class KPIMTEXTEDIT_TESTS_EXPORT InsertHtmlDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit InsertHtmlDialog(QWidget *parent = nullptr);
-    ~InsertHtmlDialog();
+    ~InsertHtmlDialog() override;
     Q_REQUIRED_RESULT QString html() const;
     void setSelectedText(const QString &str);
 
