@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,7 +11,8 @@
 #include <QDialog>
 #include <QUrl>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class InsertImageDialogPrivate;
 
 class InsertImageDialog : public QDialog
@@ -19,7 +20,7 @@ class InsertImageDialog : public QDialog
     Q_OBJECT
 public:
     explicit InsertImageDialog(QWidget *parent = nullptr);
-    ~InsertImageDialog();
+    ~InsertImageDialog() override;
 
     Q_REQUIRED_RESULT int imageWidth() const;
     Q_REQUIRED_RESULT int imageHeight() const;
