@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,7 +11,8 @@
 
 #include <QDialog>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class SelectSpecialCharDialogPrivate;
 /**
  * @brief The SelectSpecialCharDialog class
@@ -22,7 +23,7 @@ class KPIMTEXTEDIT_EXPORT SelectSpecialCharDialog : public QDialog
     Q_OBJECT
 public:
     explicit SelectSpecialCharDialog(QWidget *parent);
-    ~SelectSpecialCharDialog();
+    ~SelectSpecialCharDialog() override;
 
     void setCurrentChar(QChar c);
     Q_REQUIRED_RESULT QChar currentChar() const;
