@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #include "textgotolinewidget.h"
 
 #include <KLocalizedString>
-#include <QPushButton>
 #include <QIcon>
+#include <QPushButton>
 
 #include <QHBoxLayout>
 #include <QKeyEvent>
@@ -33,9 +33,9 @@ TextGoToLineWidget::TextGoToLineWidget(QWidget *parent)
     : QWidget(parent)
     , d(new KPIMTextEdit::TextGoToLineWidgetPrivate)
 {
-    auto *hbox = new QHBoxLayout(this);
+    auto hbox = new QHBoxLayout(this);
     hbox->setContentsMargins(2, 2, 2, 2);
-    auto *closeBtn = new QToolButton(this);
+    auto closeBtn = new QToolButton(this);
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setIconSize(QSize(16, 16));
     closeBtn->setToolTip(i18n("Close"));
@@ -50,7 +50,7 @@ TextGoToLineWidget::TextGoToLineWidget(QWidget *parent)
 
     QLabel *lab = new QLabel(i18n("Go to Line:"));
     hbox->addWidget(lab);
-    d->mSpinbox = new QSpinBox;
+    d->mSpinbox = new QSpinBox(this);
     d->mSpinbox->setMinimum(1);
     d->mSpinbox->setObjectName(QStringLiteral("line"));
     connect(d->mSpinbox, &QSpinBox::editingFinished, this, &TextGoToLineWidget::slotGoToLine);
@@ -62,6 +62,7 @@ TextGoToLineWidget::TextGoToLineWidget(QWidget *parent)
     hbox->addWidget(d->mGoToLine);
     hbox->addStretch();
     d->mSpinbox->setFocus();
+    d->mSpinbox->installEventFilter(this);
 }
 
 TextGoToLineWidget::~TextGoToLineWidget()
@@ -73,6 +74,20 @@ TextGoToLineWidget::~TextGoToLineWidget()
     delete d;
 }
 
+bool TextGoToLineWidget::eventFilter(QObject *obj, QEvent *event)
+{
+    if (obj == d->mSpinbox) {
+        if (event->type() == QEvent::KeyPress) {
+            auto e = static_cast<QKeyEvent *>(event);
+            if (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) {
+                slotGoToLine();
+                return true;
+            }
+        }
+    }
+    return QObject::eventFilter(obj, event);
+}
+
 void TextGoToLineWidget::setMaximumLineCount(int max)
 {
     d->mSpinbox->setMaximum(max);
@@ -119,7 +134,7 @@ bool TextGoToLineWidget::event(QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        auto *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->accept();
             slotCloseBar();
