@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -71,7 +71,8 @@ void TextToSpeechActions::setState(TextToSpeechWidget::State state)
 
 void TextToSpeechActionsPrivate::updateButtonState()
 {
-    mPlayPauseAction->setIcon(QIcon::fromTheme((mState == TextToSpeechWidget::Stop) ? QStringLiteral("media-playback-start") : QStringLiteral("media-playback-pause")));
+    mPlayPauseAction->setIcon(
+        QIcon::fromTheme((mState == TextToSpeechWidget::Stop) ? QStringLiteral("media-playback-start") : QStringLiteral("media-playback-pause")));
     mPlayPauseAction->setEnabled((mState != TextToSpeechWidget::Stop));
     const QString text = (mState != TextToSpeechWidget::Play) ? i18n("Pause") : i18n("Play");
     mPlayPauseAction->setToolTip(text);
