@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,16 +7,17 @@
 #ifndef TEXTTOSPEECHCONFIGDIALOG_H
 #define TEXTTOSPEECHCONFIGDIALOG_H
 
-#include <QDialog>
 #include "kpimtextedit_private_export.h"
-namespace KPIMTextEdit {
+#include <QDialog>
+namespace KPIMTextEdit
+{
 class TextToSpeechConfigWidget;
 class KPIMTEXTEDIT_TESTS_EXPORT TextToSpeechConfigDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit TextToSpeechConfigDialog(QWidget *parent = nullptr);
-    ~TextToSpeechConfigDialog();
+    ~TextToSpeechConfigDialog() override;
 
 private:
     void slotAccepted();
