@@ -1,26 +1,26 @@
 /*
-    SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testgenerateplaintextbuildergui.h"
-#include <QVBoxLayout>
+#include <KPIMTextEdit/MarkupDirector>
+#include <KPIMTextEdit/PlainTextMarkupBuilder>
 #include <QApplication>
 #include <QLabel>
-#include <QTextEdit>
 #include <QPushButton>
-#include <KPIMTextEdit/PlainTextMarkupBuilder>
-#include <KPIMTextEdit/MarkupDirector>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
 TestGeneratePlainTextBuilderGui::TestGeneratePlainTextBuilderGui(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QLabel *lab = new QLabel(QStringLiteral("html text"), this);
     mainLayout->addWidget(lab);
 
-    auto *htmlEdit = new QTextEdit(this);
+    auto htmlEdit = new QTextEdit(this);
     htmlEdit->setAcceptRichText(false);
     mainLayout->addWidget(htmlEdit);
 
@@ -30,7 +30,7 @@ TestGeneratePlainTextBuilderGui::TestGeneratePlainTextBuilderGui(QWidget *parent
     lab = new QLabel(QStringLiteral("Generate Html"), this);
     mainLayout->addWidget(lab);
 
-    auto *generatedHtml = new QTextEdit(this);
+    auto generatedHtml = new QTextEdit(this);
     generatedHtml->setAcceptRichText(false);
     generatedHtml->setReadOnly(true);
     mainLayout->addWidget(generatedHtml);
@@ -38,13 +38,12 @@ TestGeneratePlainTextBuilderGui::TestGeneratePlainTextBuilderGui(QWidget *parent
     lab = new QLabel(QStringLiteral("Plaintext from Grantlee to TextEdit"), this);
     mainLayout->addWidget(lab);
 
-    auto *generatedPlainTextFromGrantleeToTextEdit = new QTextEdit(this);
+    auto generatedPlainTextFromGrantleeToTextEdit = new QTextEdit(this);
     generatedPlainTextFromGrantleeToTextEdit->setAcceptRichText(false);
     generatedPlainTextFromGrantleeToTextEdit->setReadOnly(true);
     mainLayout->addWidget(generatedPlainTextFromGrantleeToTextEdit);
 
-
-    connect(generateHtmlFromQTextEditButton, &QPushButton::clicked, this, [=]{
+    connect(generateHtmlFromQTextEditButton, &QPushButton::clicked, this, [=] {
         generatedHtml->setHtml(htmlEdit->toPlainText());
 
         auto hb = new KPIMTextEdit::PlainTextMarkupBuilder();
@@ -59,10 +58,8 @@ TestGeneratePlainTextBuilderGui::TestGeneratePlainTextBuilderGui(QWidget *parent
 
 TestGeneratePlainTextBuilderGui::~TestGeneratePlainTextBuilderGui()
 {
-
 }
 
-
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
